package cn.estsh.i3plus.core.apiservice.controller;

import cn.estsh.i3plus.icloud.wms.sdk.IWmsScheduleJobCloud;
import cn.estsh.i3plus.platform.common.util.PlatformConstWords;
import cn.estsh.i3plus.pojo.base.bean.BaseResultBean;
import cn.estsh.impp.framework.base.controller.CoreBaseController;
import cn.estsh.impp.framework.boot.util.ResultBean;
import cn.estsh.impp.framework.boot.quartz.ScheduleTool;
import cn.estsh.impp.framework.boot.quartz.TaskInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * @Description :
 * @Reference :
 * @Author : alwaysfrin
 * @CreateDate : 2018-09-26 10:34
 * @Modify:
 **/
@RestController
@Api(description="定时任务demo")
@RequestMapping(PlatformConstWords.BASE_URL + "/schedule")
public class DemoScheduleController extends CoreBaseController{
    private static final Logger LOGGER = LoggerFactory.getLogger(DemoScheduleController.class);

    /************ 定时任务demo *********/
    @Autowired
    private ScheduleTool scheduleTool;

    @Autowired
    private IWmsScheduleJobCloud wmsScheduleJobCloud;

    @GetMapping(value="/list-task")
    @ApiOperation(value="查询定时任务",notes="查询所有定时任务")
    public ResultBean listTask(int sourceType){
        List<TaskInfo> taskList = null;
        if(sourceType == 1) {
            //本地任务
            taskList = ScheduleTool.queryJobList(scheduleTool.getScheduler());
            if(taskList != null) {
                for (TaskInfo ti : taskList) {
                    LOGGER.info("任务：{}",ti);
                }
            }else{
                LOGGER.info("任务列表为空");
            }
        }else if(sourceType == 2){
            //wms任务
            BaseResultBean<TaskInfo> baseResult = wmsScheduleJobCloud.listTask();
            LOGGER.info("任务数量：{}",baseResult.getResultList().size());
            taskList = baseResult.getResultList();
            if (taskList != null) {
                for (TaskInfo ti : taskList) {
                    LOGGER.info("任务：{}",ti);
                }
            } else {
                LOGGER.info("任务列表为空");
            }
        }

        return new ResultBean(true,taskList);
    }

    @GetMapping(value="/add-task")
    @ApiOperation(value="添加定时任务",notes="添加定时任务")
    public ResultBean addTask(int sourceType,
                              String packageName,String className,String jobName,String jobGroup,String cronExpression){
        if(sourceType == 1) {
            scheduleTool.addJob(new TaskInfo(packageName,className,jobName,jobGroup,cronExpression,"测试任务"));
        }else if(sourceType == 2){
            wmsScheduleJobCloud.addTask(packageName,className,jobName,jobGroup,cronExpression,"wms新任务");
        }

        return new ResultBean(true,"");
    }

    @GetMapping(value="/delete-task")
    @ApiOperation(value="删除定时任务",notes="删除定时任务")
    public ResultBean deleteTask(int sourceType,String jobName,String jobGroup){
        if(sourceType == 1) {
            scheduleTool.deleteJob(jobName,jobGroup);
        }else if(sourceType == 2){
            wmsScheduleJobCloud.deleteTask(jobName,jobGroup);
        }

        return new ResultBean(true);
    }

    @GetMapping(value="/pause-task")
    @ApiOperation(value="暂停定时任务",notes="暂停定时任务")
    public ResultBean pauseJob(int sourceType,String jobName,String jobGroup){
        if(sourceType == 1) {
            scheduleTool.pauseJob(jobName,jobGroup);
        }else if(sourceType == 2){
            wmsScheduleJobCloud.pauseJob(jobName,jobGroup);
        }

        return new ResultBean(true);
    }

    @GetMapping(value="/resume-task")
    @ApiOperation(value="继续定时任务",notes="继续定时任务")
    public ResultBean resumeJob(int sourceType,String jobName,String jobGroup){
        if(sourceType == 1) {
            scheduleTool.resumeJob(jobName,jobGroup);
        }else if(sourceType == 2){
            wmsScheduleJobCloud.resumeJob(jobName,jobGroup);
        }

        return new ResultBean(true);
    }

    @GetMapping(value="/exceute-task")
    @ApiOperation(value="立即执行定时任务",notes="立即执行定时任务")
    public ResultBean excuteJob(int sourceType,String jobName,String jobGroup){
        if(sourceType == 1) {
            scheduleTool.executeJob(jobName,jobGroup);
        }else if(sourceType == 2){
            wmsScheduleJobCloud.excuteJob(jobName,jobGroup);
        }

        return new ResultBean(true);
    }

    @GetMapping(value="/stand-by-schedule")
    @ApiOperation(value="定时器待机",notes="定时器待机")
    public ResultBean restartJob(int sourceType,String jobName,String jobGroup){
        if(sourceType == 1) {
            scheduleTool.standBySchedule();
        }else if(sourceType == 2){
            wmsScheduleJobCloud.standBySchedule();
        }

        return new ResultBean(true);
    }


    @GetMapping(value="/start-schedule")
    @ApiOperation(value="启动定时器",notes="启动定时器")
    public ResultBean startSchedule(int sourceType,String jobName,String jobGroup){
        if(sourceType == 1) {
            scheduleTool.startSchedule();
        }else if(sourceType == 2){
            wmsScheduleJobCloud.startSchedule();
        }

        return new ResultBean(true);
    }
}
